#ifndef _ftp_h
#define _ftp_h

#ifdef __cplusplus
extern "C" {
#endif

char *ftplib_lastresp;
int ftplib_debug;
void ftpInit(void);
int ftpOpen(char *host);
int ftpLogin(char *user, char *pass);
int ftpSite(char *cmd);
int ftpMkdir(char *path);
int ftpChdir(char *path);
int ftpRmdir(char *path);
int ftpNlst(char *output, char *path);
int ftpDir(char *output, char *path);
int ftpGet(char *output, char *path, char mode);
int ftpPut(char *input, char *path, char mode);
int ftpRename(char *src, char *dst);
int ftpDelete(char *fnm);
void ftpQuit(void);

#ifdef __cplusplus
}
#endif

#endif /* _ftp_h */
